<?php
/**
 * Simple admin notifications
 */
namespace Freshmail\Core;

class Notifications
{
  /**
   * @var array
   */
  private $allowedNotificationTypes = array(
    'error',
    'warning',
    'success',
    'info',
    '',
  );

  /**
   * Notifications to display
   *
   * @var array
   */
  private $notifications = [];

  public function __construct()
  {
    $notifications = get_transient('f_notifications');
    if (!empty($notifications)) {
      //load notifications if there were any saved
      $this->notifications = $notifications;
    }
  }

  public function __destruct()
  {
    // save whatever notifications are left to transient
    // if (function_exists('wp_doing_ajax') && !wp_doing_ajax()) {
      set_transient('f_notifications', $this->notifications);
    // }
  }

  /**
   * @action admin_notices
   *
   * @return void
   */
  public function printAllNotifications()
  {
    foreach ($this->notifications as $index => $notification) {
      echo '<div class="' . $notification['classes'] . ' freshmail-notice freshmail-notice-' . $index . '">';
      echo '<p>' . $notification['content'] . '</p>';
      echo '</div>';
    }

    //delete notifications after displaying
    $this->notifications = [];
  }

  /**
   * Adds notification to display
   *
   * @param string $content     - notification content
   * @param string $type        - "error" or "warning" or "success" or "info"
   * @param string $dismissable - if notification should have "x" to dismiss it
   *
   * @return void
   */
  public function addNotification(string $content, string $type = 'info', bool $isDismissable = true, string $additionalClasses = '', string $id = '')
  {
    if (!in_array(strtolower($type), $this->allowedNotificationTypes)) {
      $type = 'info';
    }

    $classes = 'notice notice-'.$type;

    if ($isDismissable) {
      $classes .= ' is-dismissible';
    }

    $classes .= ' '.$additionalClasses;

    $notification = array(
      'classes' => $classes,
      'content' => $content,
    );
    if (!empty($id)) {
      $this->notifications[$id] = $notification;
    } else {
      $this->notifications[] = $notification;
    }
  }

  /**
   * Removes notification from the list
   *
   * @param mixed $id id of notification to remove
   * @return void
   * @author MS
   */
  public function removeNotification($id = '')
  {
    if (empty($id)) {
      return;
    }
    unset($this->notifications[$id]);
  }
}
