<?php

namespace Freshmail\SetupWizard\Section;

use Freshmail\Core\Api\Api;

class Validator
{
  private ?Api $api = null;

  public function __construct(Api $api)
  {
    $this->api = $api;
  }

  /**
   * @action wp_ajax_save_wizard_data
   */
  public function verifyToken()
  {
    if (! current_user_can('manage_options')) {
      return wp_send_json_error('Operation is not allowed!! 😡');
    }

    $fields = [];
    foreach ($_POST as $key => $value) {
      if (0 === strpos($key, 'f_') && false === strpos($key, 'nonce') && 2 < strlen($key)) {
        $fields[$key] = $value;
      }
    }

    $result = true;
    $errors = [];
    foreach ($fields as $name => $value) {
      if (! empty($_POST[$name . '_nonce']) && false !== wp_verify_nonce($_POST[$name . '_nonce'], $name)) {
        $field_result = $this->saveField($name, $value);
        if (! $field_result) {
          $current_value = get_option($name, '');
          if ($current_value == $value) {
            // update_option returns false when saving the same value - overwrite result as true
            $field_result = true;
          } else {
            $errors[$name] = __('Problem saving this field.', 'freshmail');
          }
        }

        if ($field_result) {
          switch ($name) {
            case 'f_bearer_token':
                  $connection_ok = $this->api->isConnectionOk();
                  if (! $connection_ok) {
                    $field_result = false;
                    $errors[$name] = __('Couln\'t verify the API token - please check if it is correct.', 'freshmail');
                  }
                  break;
            default:
                  // do nothing
                  break;
          }
        }

        $result = $result && $field_result;
      }
    }

    if ($result && ! empty($_POST['f_setup_finished'])) {
      $this->saveField('f_setup_finished', true);
    }

    if ($result) {
      return wp_send_json_success('All fields saved');
    } else {
      return wp_send_json_error($errors);
    }
  }

  /**
   * @param mixed $value value of the option
   */
  private function saveField(string $name, $value): bool
  {
    return update_option($name, $value);
  }
}
